Method: RTX::API::CollectionV2#all_resources
- Defined in:
- lib/rtx/api/collection_v2.rb
#all_resources(&block) ⇒ Object
Allows you to loop through all of the resources within the pages specified and retrieve the records
75 76 77 78 79 80 81 |
# File 'lib/rtx/api/collection_v2.rb', line 75 def all_resources(&block) all_pages do |page| page.each do |resource| block.call(resource) end end end |