Method: RTX::API::CollectionV2#per_page
- Defined in:
- lib/rtx/api/collection_v2.rb
#per_page(num) ⇒ Object
Chainable method that allows you to set the per page number of the collection for your request
17 18 19 20 21 |
# File 'lib/rtx/api/collection_v2.rb', line 17 def per_page(num) clear if !num.nil? @options[:per_page] = num self end |